@@ -1,36 +1,15 @@
 package PNI::Finder;
-use strict;
+use PNI::Mo;
 use File::Basename;
 use File::Find;
+use File::Spec;
 use Module::Pluggable
   search_path => 'PNI::Node',
   require     => 1,
   inner       => 0;
 
-# This class is a singleton.
-my $self;
-
 my $PNI_dir = File::Basename::dirname(__FILE__);
-
-# return $self : PNI::Finder
-sub instance {
-
-    if ( not defined $self ) {
-
-        #-------------------------------------------------------
-        # It was
-        #
-        # $self = bless \__PACKAGE__, __PACKAGE__;
-        #
-        # but it is not supported by perl 5.8, see
-        # https://rt.cpan.org/Public/Bug/Display.html?id=69733
-        #-------------------------------------------------------
-
-        $self = bless \my $singleton, __PACKAGE__;
-    }
-
-    return $self;
-}
+my $PNI_Scenario_dir = File::Spec->catfile($PNI_dir,'Scenario');
 
 # return @nodes : PNI::Node
 sub nodes {
@@ -52,7 +31,7 @@ sub files {
             },
             no_chdir => 1,
         },
-        $PNI_dir
+        $PNI_Scenario_dir
     );
 
     return @pni_files;
@@ -69,16 +48,13 @@ PNI::Finder - searches for available nodes
 
     my $find = PNI::Finder->instance;
     my @node_list = $find->nodes;
+    my @pni_files = $find->files;
 
 =head1 METHODS
 
-=head2 C<instance>
+=head2 files
 
-    my $find = PNI::Finder->instance
-
-Returns the only instance of this class.
-
-=head2 C<nodes>
+=head2 nodes
 
     $find->nodes
 
